#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uuid
version:              1.3.16.1
visibility:           public
id:                   uuid-1.3.16.1-B8dHM40up0W32eC5wrEUud
key:                  uuid-1.3.16.1-B8dHM40up0W32eC5wrEUud
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Antoine Latter
homepage:             https://github.com/haskell-hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  8b3eed9d8ee124383d278b7ab67d9fd3
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uuid
hs-libraries:         HSuuid-1.3.16.1-B8dHM40up0W32eC5wrEUud
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cryptohash-md5-0.11.101.0-Ja7yx0XVgs5260i48DyEWv
    cryptohash-sha1-0.11.101.0-Lov2ggmHgUjLR1ewQZW1C1
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    network-info-0.2.1-1ELhTO025aF3xbpJiZvy4m
    random-1.2.1.3-EZAJJDcAdrKCzLsP4iSxFh time-1.12.2
    uuid-types-1.0.6-Cts4LAgfNqGLlNq2heOTT6

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

